@@ -1,10 +1,10 @@
+import os
 import traceback
 
 from sys import exit
 from ast import literal_eval
 from typing import Any, Dict
 from cosecurity_amqp_lib.logger import logger
-from cosecurity_amqp_lib.setting import Setting
 from pika import BlockingConnection, ConnectionParameters
 
 
@@ -13,13 +13,20 @@ class Consumer:
     queue consumer with a general handler to handle posted messages
     """
     def __init__(self, name:str) -> None:
-        self._queue_name = Setting.QUEUE.get(name.upper(), None)
+        self._host = os.getenv('AMQP_HOST', None)
+        if self._host is None:
+            raise Exception('The environment variable AMQP_HOST is required for operation')
+
+        self._heartbeat = os.getenv('AMQP_HEARTBEAT', None)
+        if self._heartbeat is None:
+            raise Exception('The environment variable AMQP_HEARTBEAT is required for operation')
+        self._heartbeat = eval(self._heartbeat)
+
+        self._queue_name = os.getenv(f'{name.upper()}_QUEUE', None)
         if self._queue_name is None:
             raise Exception('Queue not found in configuration file, please review!')
 
         self._name = name
-        self._host = Setting.AMQP_HOST
-        self._heartbeat = Setting.HEARTBEAT
         self._handlers = {}
 
     def register(self, handler:Any) -> bool:
