@@ -1,10 +1,10 @@
+import os
 import json
 import numpy as np
 
 from typing import Any, Dict
 from json import JSONEncoder
 from cosecurity_amqp_lib.logger import logger
-from cosecurity_amqp_lib.setting import Setting
 from pika import BlockingConnection, ConnectionParameters
 
 
@@ -34,11 +34,17 @@ class ProducerChannel:
 
 class Producer:
     def __init__(self) -> None:
-        self._host = Setting.AMQP_HOST
-        self._heartbeat = Setting.HEARTBEAT
+        self._host = os.getenv('AMQP_HOST', None)
+        if self._host is None:
+            raise Exception('The environment variable AMQP_HOST is required for operation')
+
+        self._heartbeat = os.getenv('AMQP_HEARTBEAT', None)
+        if self._heartbeat is None:
+            raise Exception('The environment variable AMQP_HEARTBEAT is required for operation')
+        self._heartbeat = eval(self._heartbeat)
 
     def send_message(self, destination:str, primitive:str, content:Dict[str, Any]) -> None:
-        destination_queue = Setting.QUEUE.get(destination.upper(), None)
+        destination_queue = os.getenv(f'{destination.upper()}_QUEUE', None)
         if destination_queue is None:
             raise Exception('Recipient queue not found in configuration file, please review!')
 
