@@ -38,15 +38,15 @@ class ExampleStub(Stub):
             }
         )
 
-class DetectionStub(Stub):
+class ObjectDetectionStub(Stub):
     def __init__(self):
         super().__init__(
-            destination='detection_model'
+            destination='object_detection'
         )
 
-    def find_objects(self, image_id:str, image:np.ndarray) -> None:
+    def find(self, image_id:str, image:np.ndarray) -> None:
         self._send(
-            primitive='find_objects',  
+            primitive='find',  
             content={
                 'image_id': image_id,
                 'image': image
